MockFirebaseStorage class
- Implemented types
-
- FirebasePluginPlatform
Constructors
Properties
- app ↔ FirebaseApp
-
The
FirebaseAppfor this currentFirebaseStorageinstance.getter/setter pairinherited - bucket ↔ String
-
The storage bucket of this instance.
getter/setter pairinherited-setteroverride-getter
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxDownloadRetryTime → Duration
-
The maximum time to retry downloads in milliseconds.
no setterinherited
- maxOperationRetryTime → Duration
-
The maximum time to retry operations other than uploads or downloads in milliseconds.
no setterinherited
- maxUploadRetryTime → Duration
-
The maximum time to retry uploads in milliseconds.
no setterinherited
- pluginConstants → Map
-
Returns any plugin constants this plugin app instance has initialized.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storedDataMap → _StoredDataMap
-
final
-
storedSettableMetadataMap
→ Map<
String, Map< String, dynamic> > -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
override
-
ref(
[String? path]) → Reference -
Returns a new
Reference.override -
refFromURL(
String url) → Reference -
Returns a new
Referencefrom a given URL.override -
setMaxDownloadRetryTime(
Duration time) → void -
Sets the new maximum download retry time.
inherited
-
setMaxOperationRetryTime(
Duration time) → void -
Sets the new maximum operation retry time.
inherited
-
setMaxUploadRetryTime(
Duration time) → void -
Sets the new maximum upload retry time.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
useStorageEmulator(
String host, int port, {bool automaticHostMapping = true}) → Future< void> -
Changes this instance to point to a Storage emulator running locally.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited